izulu
#####

.. image:: https://repository-images.githubusercontent.com/766241795/85494614-5974-4b26-bfec-03b8e393c7f0
   :width: 128px

|

    *"The exceptional library"*

|


**Installation**

.. include:: docs/source/user/install.rst
   :start-line: 5

.. include:: docs/source/user/intro.rst


Quickstart
==========

.. include:: docs/source/user/quickstart.rst
   :start-line: 6

Specifications
**************

``izulu`` bases on class definitions to provide handy instance creation.


.. include:: docs/source/specs/pillars.rst
   :start-line: 3

.. include:: docs/source/specs/mechanics.rst

Features
========

.. include:: docs/source/specs/toggles.rst
   :start-line: 3

.. include:: docs/source/specs/validations.rst

.. include:: docs/source/specs/additional.rst

.. include:: docs/source/user/recipes.rst

.. include:: docs/source/dev/index.rst
   :start-line: 6


Authors
*******

-  **Dima Burmistrov** - *Initial work* -
   `pyctrl <https://github.com/pyctrl>`__

*Special thanks to* `Eugene Frolov <https://github.com/phantomii/>`__ *for inspiration.*


License
*******

This project is licensed under the X11 License (extended MIT) - see the
`LICENSE <https://github.com/pyctrl/izulu/blob/main/LICENSE>`__ file for details
